If you would like to contribute to the development of OpenStack, you must
follow the steps in this page:

   http://docs.openstack.org/infra/manual/developers.html

If you already have a good understanding of how the system works and your
OpenStack accounts are set up, you can skip to the development workflow
section of this documentation to learn how changes to OpenStack should be
submitted for review via the Gerrit tool:

   http://docs.openstack.org/infra/manual/developers.html#development-workflow

Sushy is a project under the Bare Metal (ironic) program and shares many
common elements of the developer experience with ironic. You can find useful
information about running unit tests or integrated testing environments in the
ironic developer quickstart:

   https://docs.openstack.org/ironic/latest/contributor/dev-quickstart.html

Bugs should be filed in launchpad, not GitHub:

   https://bugs.launchpad.net/sushy


This repo is mirrored to Github. Issues, Pull Requests, and other Github
features of this repo are not used. https://opendev.org/openstack/sushy is
the canonical version of this repo.
